@@ -6,19 +6,18 @@ import json
 import re
 import sys
 
-from dateutil import tz
-from dateutil import parser
+from dateutil import parser, tz
 from rich.console import Console
 from rich.table import Table
 
+from suite_py.commands.login import Login
 from suite_py.lib import logger
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
+from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.qainit_handler import QainitHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
-from suite_py.lib.handler.drone_handler import DroneHandler
-from suite_py.commands.login import Login
 
 
 class QA:
