@@ -134,10 +134,16 @@ class Release:
 
     def _deploy(self, version=""):
         if len(self._countries) > 1:
-            countries = prompt_utils.ask_multiple_choices(
-                "Which countries do you want to deploy to?",
-                self._countries,
-            )
+            while True:
+                countries = prompt_utils.ask_multiple_choices(
+                    "Which countries do you want to deploy to?",
+                    self._countries,
+                )
+                if countries:
+                    break
+                logger.warning(
+                    "You didn't select any country, press SPACEBAR to select countries to deploy to, then press ENTER to confirm!"
+                )
         else:
             countries = self._countries
 
@@ -148,7 +154,9 @@ class Release:
             versions[country] = self._get_current_version(country)
 
         if self._tags_drifted(versions):
-            logger.warning("NOTE: one or more countries runs older tags.")
+            logger.warning(
+                "NOTE: one or more countries runs older tags or tag hasn't been found."
+            )
 
         if not version:
             releases = self._extract_releases(versions)
@@ -201,11 +209,14 @@ class Release:
 
     def _get_current_version(self, country):
         try:
+            logger.info("Retrieving latest version, this may take some time...")
             # get latest 10 tags
-            tags = self._github.get_tags(self._project)[0:9]
-            # retrieve specific promotion for all tags
+            tags = self._github.get_tags(self._project)
+            #  exclude tags that don't match semver notation
+            semver_tags = [t for t in tags if semver.VersionInfo.isvalid(t.name)][0:9]
+
             builds = []
-            for tag in tags:
+            for tag in semver_tags:
                 for b in self._drone.get_builds_from_tag(tag.name):
                     if (
                         b["event"] == "promote"
@@ -216,6 +227,13 @@ class Release:
                     ):
                         builds.append(b)
 
+            if not builds:
+                # may end up here if there isn't any successfull build for latest 10 tags
+                logger.error(
+                    "An error has occured retrieving current version during rollback.\nPlease ask #team-devops for help."
+                )
+                sys.exit(255)
+
             # get latest build using build number as key
             current_build = max(builds, key=lambda x: x["number"])
 
@@ -223,14 +241,17 @@ class Release:
                 logger.error(
                     f"Unable to determine current version for country {country}"
                 )
-                return None
+                sys.exit(255)
 
             v = semver.VersionInfo.parse(current_build["params"]["DRONE_TAG"])
             logger.info(f"Current version for country {country}: {v}")
 
             return v
         except Exception:
-            return None
+            logger.error(
+                "An error has occured retrieving current version during rollback.\nPlease ask #team-devops for help."
+            )
+            sys.exit(255)
 
     def _create_release(self, new_version, message):
         new_release = self._repo.create_git_release(
@@ -357,7 +378,7 @@ class Release:
             for c, v in versions.items():
                 if country == c:
                     continue
-                if version.compare(v) != 0:
+                if None in [v, version] or version.compare(v) != 0:
                     return True
         return False
 
